#include <QDomDocument>
#include <QModelIndex>
#include <QFile>
#include <QtGui>
#include <QString>
#include <QVariant>

#include "dommodel.h"
#include "mainwindow.h"

#include "treeview.h"

MainWindow::MainWindow() : QMainWindow(), model(0)
{
    fileMenu = menuBar()->addMenu(tr("&File"));
    fileMenu->addAction(tr("&Open..."), this, SLOT(openFile()),
                        QKeySequence(tr("Ctrl+O")));

    fileMenu->addSeparator();

    fileMenu->addAction(tr("findID"), this, SLOT(findIDD()),
                        QKeySequence(tr("Ctrl+F")));

    fileMenu->addSeparator();

    fileMenu->addAction(tr("E&xit"), this, SLOT(close()),
                        QKeySequence(tr("Ctrl+Q")));

    model = new DomModel(QDomDocument(), this);
    view = new TreeView(this);
    view->setModel(model);

    QFont fc;
    QFontInfo info(fc);
    fc.setPointSize(10);
    setFont(fc);


    setCentralWidget(view);
    setWindowTitle(tr("Simple DOM Model"));
}

MainWindow::~MainWindow()
{
    delete  view;
    delete  model;
}

void MainWindow::openFile()
{
    QString filePath = QFileDialog::getOpenFileName(this, tr("Open File"),
        xmlPath, tr("CFG files (*.cfg);;XML files (*.xml);;"));

    if (!filePath.isEmpty())
    {
        QFile file(filePath);
        if (file.open(QIODevice::ReadOnly))
        {
            QDomDocument document;
            if (document.setContent(&file))
            {
                DomModel *newModel = new DomModel(document, this);
                view->setModel(newModel);
                delete model;
                model = newModel;
                xmlPath = filePath;
            }
            file.close();
        }
    }
}

void MainWindow::findIDD()
{
    int idd = QInputDialog::getInt(this, tr("Find Idd Object"), tr("Idd: "));
    QModelIndex idx = model->findIDD(idd);
    if (idx.isValid())
    {
        view->scrollTo( idx );
        view->setCurrentIndex( idx );
    }
}

